@@ -1,6 +1,5 @@
 //! Aggregate Values
 #![allow(dead_code)]
-
 use crate::column::{ColumnFun, ColumnSingle};
 use crate::comp::{Comp, CompMaker};
 use crate::prelude::*;
@@ -1370,7 +1369,9 @@ impl AggMaker {
     }
     fn do_add_alias(old_name: &'static str, new_name: &'static str) -> Result<()> {
         if MODIFIERS.contains(&new_name) {
-            return err!("You can't add an alias named {} because that is reserved for a modifier");
+            return err!(
+                "You can't add an alias named {new_name} because that is reserved for a modifier"
+            );
         }
         let m = AggMakerAlias { old_name, new_name };
         let mut mm = AGG_ALIAS.lock().unwrap();
@@ -1388,7 +1389,7 @@ impl AggMaker {
         F: Fn(&str) -> Result<Rc<RefCell<dyn Agg>>> + Send,
     {
         if MODIFIERS.contains(&tag) {
-            return err!("You can't add a agg named {} because that is reserved for a modifier");
+            return err!("You can't add a agg named {tag} because that is reserved for a modifier");
         }
         let m = AggMakerItem {
             tag,
@@ -1411,7 +1412,7 @@ impl AggMaker {
     {
         if MODIFIERS.contains(&tag) {
             return err!(
-                "You can't add a counter named {} because that is reserved for a modifier"
+                "You can't add a counter named {tag} because that is reserved for a modifier"
             );
         }
         let m = CounterMakerItem {
