@@ -5,10 +5,10 @@ use cdx::expr::{calc, parse_fmt_expr};
 use cdx::prelude::*;
 use cdx::util::get_writer;
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Evaluate Formatted Expressions.", args::FileCount::Many);
     const A: [ArgSpec; 1] = [arg! {"fmt", "f", "Format", "How to format values."}];
-    let (args, files) = args::parse(&prog, &A, argv)?;
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
     let mut fmt = NumFormat::default();
     for x in args {
         if x.name == "fmt" {
@@ -30,7 +30,7 @@ pub fn main(argv: &[String]) -> Result<()> {
             fmt = f2;
             match calc(exp) {
                 Ok(v) => {
-                    fmt.print(v, &mut w)?;
+                    fmt.print(v, &mut w.0)?;
                     w.write_all(b"\n")?;
                     w.flush()?;
                 }
