@@ -1,26 +1,21 @@
 use crate::prelude::*;
 use cdx::column::*;
 use cdx::prelude::*;
-use cdx::util::{HeaderChecker, HeaderMode, HEADER_MODE};
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Select columns", args::FileCount::Many);
-    const A: [ArgSpec; 6] = [
+    const A: [ArgSpec; 5] = [
         arg! {"fields", "f", "Columns", "the columns to select."},
         arg! {"group", "g", "Columns", "the columns in a bunch, e.g. '.group:1-3'"},
         arg! {"expr", "e", "Name:Expr", "The result of an arithmetic expression"},
         arg! {"composite", "c", "Spec", "new value made from parts. e.g. 'stuff:abc^{two}def'"},
-        arg_enum! {"header", "h", "Mode", "header requirements", &HEADER_MODE},
         arg_enum! {"dups", "D", "Mode", "Duplicate Column Handling", &["Fail", "Allow", "Numeric"]},
     ];
-    let (args, files) = args::parse(&prog, &A, argv)?;
-    let mut checker = HeaderChecker::new();
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
     let mut header = ColumnHeader::new();
     let mut v = Writer::new(b'\t');
     for x in args {
-        if x.name == "header" {
-            checker.mode = HeaderMode::from_str(&x.value)?;
-        } else if x.name == "dups" {
+        if x.name == "dups" {
             header.set_handling(DupColHandling::new(&x.value)?);
         } else if x.name == "fields" {
             v.push(Box::new(ReaderColumns::new(ColumnSet::from_spec(
@@ -38,9 +33,7 @@ pub fn main(argv: &[String]) -> Result<()> {
     }
 
     if v.is_empty() {
-        return Err(Error::Error(
-            "cut requires at lease one --columns or --groups".to_string(),
-        ));
+        bail!("cut requires at lease one --columns or --groups");
     }
 
     let mut w = get_writer("-")?;
@@ -58,14 +51,14 @@ pub fn main(argv: &[String]) -> Result<()> {
         if f.has_header() {
             not_header = header.get_head(b'\t');
         }
-        if checker.check(not_header.as_bytes(), x)? {
+        if settings.checker.check(not_header.as_bytes(), x)? {
             w.write_all(not_header.as_bytes())?;
         }
         if f.is_done() {
             continue;
         }
         loop {
-            v.write(&mut w, f.curr())?;
+            v.write(&mut w.0, f.curr())?;
             if f.getline()? {
                 break;
             }
