@@ -1,4 +1,5 @@
-use cdx::util::{Error, Result};
+use cdx::prelude::*;
+use cdx::util::{silent, suppress};
 use std::env;
 
 pub mod args;
@@ -21,14 +22,16 @@ mod transpose_main;
 mod uniq_main;
 mod verify_main;
 mod wc_main;
+use crate::globals::Settings;
 
 fn main() {
-    match inner_main(env::args().collect()) {
+    let mut settings = Settings::new();
+    match inner_main(env::args().collect(), &mut settings) {
         Err(e) => {
-            if e.suppress() {
+            if suppress(&e) {
                 std::process::exit(0);
             }
-            if e.silent() {
+            if silent(&e) {
                 std::process::exit(1);
             }
             eprintln!("Error\t{}", e);
@@ -45,11 +48,11 @@ fn main() {
     }
 }
 
-fn inner_main(mut args: Vec<String>) -> Result<()> {
+pub fn inner_main(mut args: Vec<String>, settings: &mut Settings) -> Result<()> {
     if args.len() < 2 {
         eprintln!("USAGE : cdx <command> [options...]");
         eprintln!("Type 'cdx help' for more details");
-        return Err(Error::Silent);
+        return cdx_err(CdxError::Silent);
     }
     if args[1] == "help" || args[1] == "--help" {
         println!("USAGE : cdx <command> [options...]");
@@ -68,12 +71,12 @@ fn inner_main(mut args: Vec<String>) -> Result<()> {
             let arg1 = args.remove(1);
             args[0] += " ";
             args[0] += &arg1;
-            return (x.proc)(&args);
+            return (x.proc)(&args, settings);
         }
     }
     eprintln!("Valid subcommands are :");
     for x in cdxmain::MAINLIST {
         eprintln!("{:8} : {}", x.name, x.help);
     }
-    Err(Error::Silent)
+    cdx_err(CdxError::Silent)
 }
