@@ -1,4 +1,6 @@
 //! The prelude
 
 pub use crate::args::ArgSpec;
+pub use crate::globals::Settings;
 pub use crate::{arg, arg_enum, arg_pos, args};
+pub use anyhow::bail;
