@@ -11,10 +11,10 @@ fn print_centered(txt: &str, width: usize) {
     }
 }
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Display files.", args::FileCount::Many);
     const A: [ArgSpec; 1] = [arg! {"end", "e", "",  "nothing"}];
-    let (args, files) = args::parse(&prog, &A, argv)?;
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
 
     let mut end = false;
 
