@@ -2,7 +2,7 @@ use crate::prelude::*;
 use cdx::prelude::*;
 use cdx::tooltest::*;
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Select uniq lines.", args::FileCount::Many);
     const A: [ArgSpec; 4] = [
         arg! {"verbose", "v", "", "Print name of each test before execution."},
@@ -10,7 +10,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"tmp", "t", "Dir", "Use this as a persistant tmp dir, rather than creating an ephemeral one."},
         arg! {"file-format", "", "", "Describe format for '.test' files."},
     ];
-    let (args, files) = args::parse(&prog, &A, argv)?;
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
     let mut config = Config::new()?;
     let mut verbose = false;
     for x in args {
