@@ -1,13 +1,13 @@
 use crate::prelude::*;
 use cdx::prelude::*;
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Transpose a file.", args::FileCount::One);
     const A: [ArgSpec; 2] = [
         arg! {"head", "h", "",  "Add ' CDX' before first line."},
         arg! {"lines", "n", "Number",  "Maximum lines to examine."},
     ];
-    let (args, files) = args::parse(&prog, &A, argv)?;
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
 
     let mut head = false;
     let mut lines = usize::MAX;
