@@ -19,7 +19,7 @@ impl NamedAgg {
     }
 }
 
-pub fn main(argv: &[String]) -> Result<()> {
+pub fn main(argv: &[String], settings: &mut Settings) -> Result<()> {
     let prog = args::ProgSpec::new("Aggregate info on whole lines.", args::FileCount::Many);
     const A: [ArgSpec; 10] = [
         arg! {"agg", "a", "NewCol,Spec", "Merge values into new column."},
@@ -28,12 +28,12 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"chars", "c", "", "Shortcut for '--agg chars,asum,utf8.chars'"},
         arg! {"words", "w", "", "Shortcut for '--agg words,asum,swords'"},
         arg! {"file", "f", "Tri,ColName", "Should we add the filename as the first column?"},
-        arg! {"header", "h", "Tri", "Should we write a cdx header?"},
+        arg! {"with-header", "h", "Tri", "Should we write a cdx header?"},
         arg! {"total", "t", "yes,no,maybe,only", "Should we write the totals line?"},
         arg! {"format", "F", "plain,float,power2,power10", "Format for output numbers."},
         arg! {"columns", "C", "", "Count each column separately."},
     ];
-    let (args, files) = args::parse(&prog, &A, argv)?;
+    let (args, files) = args::parse(&prog, &A, argv, settings)?;
 
     let mut agg = AggList::new();
     let mut file_name_col = "file".to_string();
@@ -64,7 +64,7 @@ pub fn main(argv: &[String]) -> Result<()> {
             } else {
                 show_totals = Tri::new(&x.value)?;
             }
-        } else if x.name == "header" {
+        } else if x.name == "with-header" {
             show_header = Tri::new(&x.value)?;
         } else if x.name == "file" {
             if let Some((a, b)) = x.value.split_once(',') {
@@ -153,7 +153,7 @@ pub fn main(argv: &[String]) -> Result<()> {
                     if i != 0 {
                         w.write_all(b"\t")?;
                     }
-                    x.agg.get(i).agg.borrow_mut().result(&mut w, fmt)?;
+                    x.agg.get(i).agg.borrow_mut().result(&mut w.0, fmt)?;
                 }
                 w.write_all(b"\n")?;
             }
@@ -222,7 +222,7 @@ pub fn main(argv: &[String]) -> Result<()> {
                     w.write_all(x.as_bytes())?;
                     w.write_all(b"\t")?;
                 }
-                c_write.write(&mut w, &nada)?;
+                c_write.write(&mut w.0, &nada)?;
             }
             #[allow(clippy::needless_range_loop)]
             for i in 0..agg.len() {
@@ -239,7 +239,7 @@ pub fn main(argv: &[String]) -> Result<()> {
             if i != 0 {
                 w.write_all(b"\t")?;
             }
-            fmt.print(*t, &mut w)?;
+            fmt.print(*t, &mut w.0)?;
         }
         w.write_all(b"\n")?;
     }
