@@ -930,7 +930,9 @@ impl CompMaker {
     }
     fn do_add_alias(old_name: &'static str, new_name: &'static str) -> Result<()> {
         if MODIFIERS.contains(&new_name) {
-            return err!("You can't add an alias named {} because that is reserved for a modifier");
+            return err!(
+                "You can't add an alias named {new_name} because that is reserved for a modifier"
+            );
         }
         let m = CompMakerAlias { old_name, new_name };
         let mut mm = COMP_ALIAS.lock().unwrap();
@@ -949,7 +951,7 @@ impl CompMaker {
     {
         if MODIFIERS.contains(&tag) {
             return err!(
-                "You can't add a matcher named {} because that is reserved for a modifier"
+                "You can't add a matcher named {tag} because that is reserved for a modifier"
             );
         }
         let m = CompMakerItem {
@@ -973,7 +975,7 @@ impl CompMaker {
     {
         if MODIFIERS.contains(&tag) {
             return err!(
-                "You can't add a matcher named {} because that is reserved for a modifier"
+                "You can't add a matcher named {tag} because that is reserved for a modifier"
             );
         }
         let m = LineCompMakerItem {
@@ -1954,6 +1956,7 @@ mod tests {
         test_less(b"1.2.3X", b"1.2.3.Y");
     }
     #[test]
+    #[allow(clippy::cognitive_complexity)]
     fn num_cmp() {
         assert_eq!(num_cmp_signed(b"1", b"1"), Ordering::Equal);
         assert_eq!(num_cmp_signed(b"  1", b"1"), Ordering::Equal);
