@@ -38,10 +38,8 @@ fn tail_u8_len(buff: &[u8], num: usize, delim: u8) -> usize {
 
 /// abstraction of str and [u8]
 pub trait Text {
-    // this warning seems to be a bug in rustc
-    #[allow(unused_qualifications)]
     /// the underlying type of the slice, e.g. char or u8
-    type Char: std::cmp::PartialEq + Copy;
+    type Char: PartialEq + Copy;
     /// A container for the underlying type, e.g. String or Vec<u8>
     type Container;
 
@@ -850,6 +848,7 @@ mod tests {
     }
 
     #[test]
+    #[allow(clippy::cognitive_complexity)]
     fn uwild() {
         assert!(b"".glob(b"", Case::Sens));
         assert!(!b"".glob(b"foo", Case::Sens));
@@ -916,7 +915,9 @@ mod tests {
 
         assert!("anb".glob("a?b", Case::Sens));
         assert!("añb".glob("a?b", Case::Sens));
-
+    }
+    #[test]
+    fn swild2() {
         assert!(!"aÑb".glob("añb", Case::Sens));
         assert!(!"añb".glob("aÑb", Case::Sens));
         assert!("aÑb".glob("añb", Case::Insens));
