@@ -93,6 +93,7 @@ pub fn read_dir(dir: &Path) -> Result<Vec<String>> {
 /// set need_read to false if line ends up with unexamined data
 fn grab(
     tag: &[u8],
+#[allow(clippy::ptr_arg)]
     buff: &mut Vec<u8>,
     line: &mut Vec<u8>,
     reader: &mut Infile,
@@ -101,7 +102,7 @@ fn grab(
     if let Some(x) = line.strip_prefix(tag) {
         if !x.is_empty() {
             prerr(&[b"Unexpected stuff after ", tag, b" : ", line]);
-            return Err(Error::Silent);
+            return cdx_err(CdxError::Silent);
         }
         loop {
             line.clear();
@@ -267,7 +268,6 @@ impl Test {
             let mut w = get_writer(&fname)?;
             w.write_all(&x.content)?;
         }
-        #[allow(clippy::redundant_clone)]
         let mut tmp_stdin = tmp.clone();
         tmp_stdin.push_str("stdin");
         {
@@ -296,18 +296,15 @@ impl Test {
         let res = tmp_cmd
             .stdin(std::fs::File::open(&tmp_stdin).unwrap())
             .output();
-        let output;
-        match res {
+        let output = match res {
             Err(x) => {
                 prerr(&[b"Error trying to execute : ", &basecmd]);
-                return Err(Error::IoError(x));
+                return Err(anyhow::Error::new(x));
             }
-            Ok(x) => {
-                output = x;
-            }
-        }
+            Ok(x) => x,
+        };
         let mut files = read_dir(Path::new(&tmp))?;
-        nuke(&mut files, &"stdin".to_string(), &tmp, keep_files)?;
+        nuke(&mut files, "stdin", &tmp, keep_files)?;
         for x in &self.in_files {
             nuke(&mut files, &x.name, &tmp, keep_files)?;
         }
@@ -443,7 +440,7 @@ impl Config {
             self.fail
         );
         if self.fail > 0 {
-            Err(Error::Silent)
+            cdx_err(CdxError::Silent)
         } else {
             Ok(())
         }
