@@ -3,28 +3,26 @@
 use crate::column::ColumnHeader;
 use crate::comp::{CompMaker, Compare};
 use crate::prelude::*;
+use anyhow;
 use flate2::read::MultiGzDecoder;
 use fs_err as fs;
 use lazy_static::lazy_static;
 use regex::Regex;
 use std::cmp;
 use std::error;
-use std::ffi::OsStr;
 use std::io;
 use std::ops::{Deref, DerefMut};
-use std::path::Path;
 use std::str;
 use tokio_stream::StreamExt;
 
 /// Shorthand for returning an error Result
 #[macro_export]
 macro_rules! err {
-    ($e:literal) => {Err(Error::Error($e.to_string()))};
-    ($e:expr) => {Err(Error::Error($e))};
-    ($($e:expr),+) => {Err(Error::Error(format!($($e),+)))}
+    ($($x:tt)*) => {Err(anyhow!($($x)*))}
 }
 pub use err;
 // Shorthand for implementing a pass-through error
+/*
 macro_rules! err_type {
     ($x:path, $i:path) => {
         impl From<$x> for Error {
@@ -34,32 +32,13 @@ macro_rules! err_type {
         }
     };
 }
-
+*/
 /// Common CDX error type
 #[derive(Debug)]
 #[non_exhaustive]
-#[allow(clippy::large_enum_variant)]
-pub enum Error {
+pub enum CdxError {
     /// Custom cdx error
     Error(String),
-    /// pass through ParseIntError
-    ParseIntError(std::num::ParseIntError),
-    /// pass through ParseIntError
-    ParseFloatError(std::num::ParseFloatError),
-    /// pass through io::Error
-    IoError(std::io::Error),
-    /// pass through regex::Error
-    RegexError(regex::Error),
-    /// pass through FromUtf8Error
-    FromUtf8Error(std::string::FromUtf8Error),
-    /// pass through Utf8Error
-    Utf8Error(std::str::Utf8Error),
-    /// pass through DecodeError
-    Base64(base64::DecodeError),
-    /// pass through SdkError
-    MyGetObjectError(aws_sdk_s3::SdkError<aws_sdk_s3::error::GetObjectError>),
-    /// bytestream
-    ByteStreamError(aws_smithy_http::byte_stream::Error),
     /// common error with long default string
     NeedLookup,
     /// be an error, but don't report anything
@@ -68,57 +47,41 @@ pub enum Error {
     NoError,
 }
 
+/// Common CDX error type
+pub type Error = anyhow::Error;
 /// Common CDX result type
 pub type Result<T> = core::result::Result<T, Error>;
-impl error::Error for Error {}
+impl error::Error for CdxError {}
 
-impl Error {
-    /// return true if this error should be treated as not an error
-    pub fn suppress(&self) -> bool {
-        match self {
-            Error::IoError(err) => err.kind() == io::ErrorKind::BrokenPipe,
-            Error::NoError => true,
-            _ => false,
-        }
-    }
-    /// return true if this error should be treated as an error, bu silently
-    pub const fn silent(&self) -> bool {
-        matches!(self, Error::Silent)
+/// convert CdxError to Result
+pub fn cdx_err<T>(err: CdxError) -> Result<T> {
+    Err(anyhow::Error::new(err))
+}
+
+/// if suppress(e) is true, treat as success
+pub fn suppress(err: &Error) -> bool {
+    if let Some(ioerr) = err.downcast_ref::<io::Error>() {
+        ioerr.kind() == io::ErrorKind::BrokenPipe
+    } else {
+        matches!(err.downcast_ref::<CdxError>(), Some(CdxError::NoError))
     }
 }
 
-err_type!(base64::DecodeError, Error::Base64);
-err_type!(std::str::Utf8Error, Error::Utf8Error);
-err_type!(regex::Error, Error::RegexError);
-err_type!(std::string::FromUtf8Error, Error::FromUtf8Error);
-err_type!(std::io::Error, Error::IoError);
-err_type!(std::num::ParseIntError, Error::ParseIntError);
-err_type!(std::num::ParseFloatError, Error::ParseFloatError);
-err_type!(aws_smithy_http::byte_stream::Error, Error::ByteStreamError);
-err_type!(
-    aws_sdk_s3::SdkError<aws_sdk_s3::error::GetObjectError>,
-    Error::MyGetObjectError
-);
+/// if silent(e) is true, treat as failure, but print no message
+pub fn silent(err: &Error) -> bool {
+    matches!(err.downcast_ref::<CdxError>(), Some(CdxError::Silent))
+}
 
-impl fmt::Display for Error {
+impl fmt::Display for CdxError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            Error::Error(s) => write!(f, "{}", s)?,
-            Error::ParseIntError(s) => write!(f, "ParseIntError : {}", s)?,
-            Error::ParseFloatError(s) => write!(f, "ParseFloatError : {}", s)?,
-            Error::IoError(s) => write!(f, "IoError : {}", s)?,
-            Error::RegexError(s) => write!(f, "RegexError : {}", s)?,
-            Error::FromUtf8Error(s) => write!(f, "FromUtf8Error : {}", s)?,
-            Error::Utf8Error(s) => write!(f, "Utf8Error : {}", s)?,
-            Error::MyGetObjectError(s) => write!(f, "GetObjectError : {}", s)?,
-            Error::ByteStreamError(s) => write!(f, "ByteStreamError : {}", s)?,
-            Error::Base64(s) => write!(f, "Base64 : {}", s)?,
-            Error::NeedLookup => write!(
+            CdxError::Error(s) => write!(f, "{}", s)?,
+            CdxError::NeedLookup => write!(
                 f,
                 "ColumnSet.lookup() must be called before ColumnSet.select()"
             )?,
-            Error::Silent => write!(f, "Silent")?,
-            Error::NoError => write!(f, "Not an error.")?,
+            CdxError::Silent => write!(f, "Silent")?,
+            CdxError::NoError => write!(f, "Not an error.")?,
         }
         Ok(())
     }
@@ -635,24 +598,25 @@ impl Read for S3Reader {
 pub struct Infile(
     /// The file being read
     pub io::BufReader<Box<dyn Read>>,
+    pub String,
 );
 
 impl Infile {
     /// create a new input file
-    pub fn new(f: io::BufReader<Box<dyn Read>>) -> Self {
-        Self(f)
+    pub fn new(f: io::BufReader<Box<dyn Read>>, n: &str) -> Self {
+        Self(f, n.to_string())
     }
 }
 
 impl Default for Infile {
     fn default() -> Self {
-        Self::new(io::BufReader::new(Box::new(io::empty())))
+        Self::new(io::BufReader::new(Box::new(io::empty())), "")
     }
 }
 
 impl fmt::Debug for Infile {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "Infile")
+        write!(f, "Infile : {}", self.1)
     }
 }
 
@@ -683,21 +647,51 @@ impl AsMut<io::BufReader<Box<dyn Read>>> for Infile {
 }
 
 /// output file type
-pub type Outfile = io::BufWriter<Box<dyn Write>>;
+pub struct Outfile(pub io::BufWriter<Box<dyn Write>>, pub String);
 
-/// Make an Outfile from a file name
-pub fn get_writer2<P: AsRef<Path>>(name: P) -> Result<Outfile> {
-    let name = name.as_ref().as_os_str();
-    let inner: Box<dyn Write> = {
-        if name == OsStr::new("-") {
-            Box::new(io::stdout())
-        } else if name == OsStr::new("--") {
-            Box::new(io::stderr())
-        } else {
-            Box::new(fs::OpenOptions::new().write(true).create(true).open(name)?)
-        }
-    };
-    Ok(io::BufWriter::new(inner))
+impl Outfile {
+    /// create a new input file
+    pub fn new(f: io::BufWriter<Box<dyn Write>>, n: &str) -> Self {
+        Self(f, n.to_string())
+    }
+}
+
+impl Default for Outfile {
+    fn default() -> Self {
+        Self::new(io::BufWriter::new(Box::new(io::sink())), "")
+    }
+}
+
+impl fmt::Debug for Outfile {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "Outfile : {}", self.1)
+    }
+}
+
+impl Deref for Outfile {
+    type Target = io::BufWriter<Box<dyn Write>>;
+
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+
+impl DerefMut for Outfile {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
+impl AsRef<io::BufWriter<Box<dyn Write>>> for Outfile {
+    fn as_ref(&self) -> &io::BufWriter<Box<dyn Write>> {
+        &self.0
+    }
+}
+
+impl AsMut<io::BufWriter<Box<dyn Write>>> for Outfile {
+    fn as_mut(&mut self) -> &mut io::BufWriter<Box<dyn Write>> {
+        &mut self.0
+    }
 }
 
 /// Make an Outfile from a file name
@@ -711,7 +705,7 @@ pub fn get_writer(name: &str) -> Result<Outfile> {
             Box::new(fs::OpenOptions::new().write(true).create(true).open(name)?)
         }
     };
-    Ok(io::BufWriter::new(inner))
+    Ok(Outfile::new(io::BufWriter::new(inner), name))
 }
 
 // should return Cow<>
@@ -758,7 +752,7 @@ pub fn get_reader(name: &str) -> Result<Infile> {
     if start.starts_with(&[0x1fu8, 0x8bu8, 0x08u8]) {
         outer = io::BufReader::new(Box::new(MultiGzDecoder::new(outer)));
     }
-    Ok(Infile::new(outer))
+    Ok(Infile::new(outer, name))
 }
 
 #[derive(Debug, Default)]
@@ -1347,7 +1341,7 @@ impl Default for HeaderMode {
 }
 
 /// Object to enforce HeaderMode
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct HeaderChecker {
     /// the mode to enforce
     pub mode: HeaderMode,
